@@ -1,23 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
+**
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -43,6 +61,12 @@
 
 QT_BEGIN_HEADER
 
+#if defined(Q_OS_SYMBIAN)
+class CApaApplication;
+#endif
+
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Gui)
 
 class QSessionManager;
@@ -50,17 +74,28 @@ class QDesktopWidget;
 class QStyle;
 class QEventLoop;
 class QIcon;
+#ifndef QT_NO_IM
 class QInputContext;
+#endif
 template <typename T> class QList;
 class QLocale;
 #if defined(Q_WS_QWS)
 class QDecoration;
+#elif defined(Q_WS_QPA)
+class QPlatformNativeInterface;
+#endif
+#if defined(Q_OS_SYMBIAN)
+class QSymbianEvent;
 #endif
 
 class QApplication;
 class QApplicationPrivate;
+#if defined(qApp)
+#undef qApp
+#endif
 #define qApp (static_cast<QApplication *>(QCoreApplication::instance()))
 
+
 class Q_GUI_EXPORT QApplication : public QCoreApplication
 {
     Q_OBJECT
@@ -79,16 +114,28 @@ class Q_GUI_EXPORT QApplication : public QCoreApplication
 #ifndef QT_NO_STYLE_STYLESHEET
     Q_PROPERTY(QString styleSheet READ styleSheet WRITE setStyleSheet)
 #endif
+#ifdef Q_WS_WINCE
+    Q_PROPERTY(int autoMaximizeThreshold READ autoMaximizeThreshold WRITE setAutoMaximizeThreshold)
+#endif
+    Q_PROPERTY(bool autoSipEnabled READ autoSipEnabled WRITE setAutoSipEnabled)
 
 public:
     enum Type { Tty, GuiClient, GuiServer };
+
+#ifdef Q_OS_SYMBIAN
+    typedef CApaApplication * (*QS60MainApplicationFactory)();
+#endif
+
 #ifndef qdoc
-    QApplication(int &argc, char **argv, int = QT_VERSION);
-    QApplication(int &argc, char **argv, bool GUIenabled, int = QT_VERSION);
-    QApplication(int &argc, char **argv, Type, int = QT_VERSION);
+    QApplication(int &argc, char **argv, int = ApplicationFlags);
+    QApplication(int &argc, char **argv, bool GUIenabled, int = ApplicationFlags);
+    QApplication(int &argc, char **argv, Type, int = ApplicationFlags);
 #if defined(Q_WS_X11)
-    QApplication(Display* dpy, Qt::HANDLE visual = 0, Qt::HANDLE cmap = 0, int = QT_VERSION);
-    QApplication(Display *dpy, int &argc, char **argv, Qt::HANDLE visual = 0, Qt::HANDLE cmap= 0, int = QT_VERSION);
+    QApplication(Display* dpy, Qt::HANDLE visual = 0, Qt::HANDLE cmap = 0, int = ApplicationFlags);
+    QApplication(Display *dpy, int &argc, char **argv, Qt::HANDLE visual = 0, Qt::HANDLE cmap= 0, int = ApplicationFlags);
+#endif
+#if defined(Q_OS_SYMBIAN)
+    QApplication(QApplication::QS60MainApplicationFactory factory, int &argc, char **argv, int = ApplicationFlags);
 #endif
 #endif
     virtual ~QApplication();
@@ -101,6 +148,7 @@ public:
     enum ColorSpec { NormalColor=0, CustomColor=1, ManyColor=2 };
     static int colorSpec();
     static void setColorSpec(int);
+    static void setGraphicsSystem(const QString &);
 
 #ifndef QT_NO_CURSOR
     static QCursor *overrideCursor();
@@ -152,6 +200,7 @@ public:
     static void alert(QWidget *widget, int duration = 0);
 
     static Qt::KeyboardModifiers keyboardModifiers();
+    static Qt::KeyboardModifiers queryKeyboardModifiers();
     static Qt::MouseButtons mouseButtons();
 
     static void setDesktopSettingsAware(bool);
@@ -195,6 +244,10 @@ public:
     virtual int x11ClientMessage(QWidget*, XEvent*, bool passive_only);
     int x11ProcessEvent(XEvent*);
 #endif
+#if defined(Q_OS_SYMBIAN)
+    int symbianProcessEvent(const QSymbianEvent *event);
+    virtual bool symbianEventFilter(const QSymbianEvent *event);
+#endif
 #if defined(Q_WS_QWS)
     virtual bool qwsEventFilter(QWSEvent *);
     int qwsProcessEvent(QWSEvent*);
@@ -206,12 +259,15 @@ public:
 #endif
 #endif
 
+#if defined(Q_WS_QPA)
+    static QPlatformNativeInterface *platformNativeInterface();
+#endif
+
 
 #if defined(Q_WS_WIN)
     void winFocus(QWidget *, bool);
     static void winMouseButtonUp();
 #endif
-
 #ifndef QT_NO_SESSIONMANAGER
     // session management
     bool isSessionRestored() const;
@@ -220,8 +276,11 @@ public:
     virtual void commitData(QSessionManager& sm);
     virtual void saveState(QSessionManager& sm);
 #endif
+
+#ifndef QT_NO_IM
     void setInputContext(QInputContext *);
     QInputContext *inputContext() const;
+#endif
 
     static QLocale keyboardInputLocale();
     static Qt::LayoutDirection keyboardInputDirection();
@@ -234,17 +293,24 @@ public:
     static bool quitOnLastWindowClosed();
 
 #ifdef QT_KEYPAD_NAVIGATION
-    static void setKeypadNavigationEnabled(bool);
+    static Q_DECL_DEPRECATED void setKeypadNavigationEnabled(bool);
     static bool keypadNavigationEnabled();
+    static void setNavigationMode(Qt::NavigationMode mode);
+    static Qt::NavigationMode navigationMode();
 #endif
 
 Q_SIGNALS:
     void lastWindowClosed();
     void focusChanged(QWidget *old, QWidget *now);
+    void fontDatabaseChanged();
 #ifndef QT_NO_SESSIONMANAGER
     void commitDataRequest(QSessionManager &sessionManager);
     void saveStateRequest(QSessionManager &sessionManager);
 #endif
+#ifdef Q_OS_SYMBIAN
+    void aboutToReleaseGpuResources();
+    void aboutToUseGpuResources();
+#endif
 
 public:
     QString styleSheet() const;
@@ -252,6 +318,12 @@ public Q_SLOTS:
 #ifndef QT_NO_STYLE_STYLESHEET
     void setStyleSheet(const QString& sheet);
 #endif
+#ifdef Q_WS_WINCE
+    void setAutoMaximizeThreshold(const int threshold);
+    int autoMaximizeThreshold() const;
+#endif
+    void setAutoSipEnabled(const bool enabled);
+    bool autoSipEnabled() const;
     static void closeAllWindows();
     static void aboutQt();
 
@@ -277,10 +349,12 @@ public:
 #if defined(Q_OS_MAC)
     static QT3_SUPPORT Qt::MacintoshVersion macVersion() { return (Qt::MacintoshVersion)QSysInfo::MacintoshVersion; }
 #endif
+#  ifndef QT_NO_CURSOR
     inline static  QT3_SUPPORT void setOverrideCursor(const QCursor &cursor, bool replace)
-        { if (replace) changeOverrideCursor(cursor); else setOverrideCursor(cursor); }
+    { if (replace) changeOverrideCursor(cursor); else setOverrideCursor(cursor); }
+#  endif
     inline static QT3_SUPPORT bool hasGlobalMouseTracking() {return true;}
-    inline static QT3_SUPPORT void setGlobalMouseTracking(bool) {};
+    inline static QT3_SUPPORT void setGlobalMouseTracking(bool) {}
     inline static QT3_SUPPORT void flushX() { flush(); }
     static inline QT3_SUPPORT void setWinStyleHighlightColor(const QColor &c) {
         QPalette p(palette());
@@ -290,7 +364,7 @@ public:
     static inline QT3_SUPPORT const QColor &winStyleHighlightColor()
         { return palette().color(QPalette::Active, QPalette::Highlight); }
     static inline QT3_SUPPORT void setPalette(const QPalette &pal, bool, const char* className = 0)
-        { setPalette(pal, className); };
+        { setPalette(pal, className); }
     static inline QT3_SUPPORT void setFont(const QFont &font, bool, const char* className = 0)
         { setFont(font, className); }
 
@@ -308,12 +382,19 @@ public:
     QApplication(Display* dpy, Qt::HANDLE visual = 0, Qt::HANDLE cmap = 0);
     QApplication(Display *dpy, int &argc, char **argv, Qt::HANDLE visual = 0, Qt::HANDLE cmap= 0);
 #endif
+#if defined(Q_OS_SYMBIAN) || defined(qdoc)
+    QApplication(QApplication::QS60MainApplicationFactory factory, int &argc, char **argv);
+#endif
 #endif
 
 private:
     Q_DISABLE_COPY(QApplication)
     Q_DECLARE_PRIVATE(QApplication)
 
+    friend class QGraphicsWidget;
+    friend class QGraphicsItem;
+    friend class QGraphicsScene;
+    friend class QGraphicsScenePrivate;
     friend class QWidget;
     friend class QWidgetPrivate;
     friend class QETWidget;
@@ -322,8 +403,11 @@ private:
     friend class QWidgetAnimator;
 #ifndef QT_NO_SHORTCUT
     friend class QShortcut;
+    friend class QLineEdit;
+    friend class QTextControl;
 #endif
     friend class QAction;
+    friend class QFontDatabasePrivate;
 
 #if defined(Q_WS_QWS)
     friend class QInputContext;
@@ -331,13 +415,23 @@ private:
     friend class QDirectPainter;
     friend class QDirectPainterPrivate;
 #endif
+#ifndef QT_NO_GESTURES
+    friend class QGestureManager;
+#endif
 
-    Q_PRIVATE_SLOT(d_func(), void _q_tryEmitLastWindowClosed())
 #if defined(Q_WS_MAC) || defined(Q_WS_X11)
     Q_PRIVATE_SLOT(d_func(), void _q_alertTimeOut())
 #endif
+#if defined(QT_RX71_MULTITOUCH)
+    Q_PRIVATE_SLOT(d_func(), void _q_readRX71MultiTouchEvents())
+#endif
+#if defined(Q_OS_SYMBIAN)
+    Q_PRIVATE_SLOT(d_func(), void _q_aboutToQuit())
+#endif
 };
 
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
 #endif // QAPPLICATION_H
