@@ -1,23 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
+**
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -28,32 +46,40 @@
 
 QT_BEGIN_HEADER
 
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Core)
 
 template <class Key, class T>
 class QCache
 {
     struct Node {
-        inline Node() {}
-        inline Node(const Key &key, T *data, int cost)
-            : k(key), t(data), c(cost), p(0), n(0) {}
-        Key k; T *t; int c; Node *p,*n;
+        inline Node() : keyPtr(0) {}
+        inline Node(T *data, int cost)
+            : keyPtr(0), t(data), c(cost), p(0), n(0) {}
+        const Key *keyPtr; T *t; int c; Node *p,*n;
     };
     Node *f, *l;
     QHash<Key, Node> hash;
-    QHash<int, Node> serial;
+    void *unused; // ### Qt5: remove
     int mx, total;
+
     inline void unlink(Node &n) {
         if (n.p) n.p->n = n.n;
         if (n.n) n.n->p = n.p;
         if (l == &n) l = n.p;
         if (f == &n) f = n.n;
         total -= n.c;
-        delete n.t;
-        hash.remove(Key(n.k));
+        T *obj = n.t;
+        hash.remove(*n.keyPtr);
+        delete obj;
     }
-    inline T *&relink(const Key &key) {
-        Node &n = hash[key];
+    inline T *relink(const Key &key) {
+        typename QHash<Key, Node>::iterator i = hash.find(key);
+        if (typename QHash<Key, Node>::const_iterator(i) == hash.constEnd())
+            return 0;
+
+        Node &n = *i;
         if (f != &n) {
             if (n.p) n.p->n = n.n;
             if (n.n) n.n->p = n.p;
@@ -106,7 +132,7 @@ private:
 
 template <class Key, class T>
 inline QCache<Key, T>::QCache(int amaxCost)
-    : f(0), l(0), mx(amaxCost), total(0) {}
+    : f(0), l(0), unused(0), mx(amaxCost), total(0) {}
 
 template <class Key, class T>
 inline void QCache<Key,T>::clear()
@@ -119,8 +145,7 @@ inline void QCache<Key,T>::setMaxCost(int m)
 
 template <class Key, class T>
 inline T *QCache<Key,T>::object(const Key &key) const
-{ if (!hash.contains(key)) return 0;
- return const_cast<QCache<Key,T>*>(this)->relink(key); }
+{ return const_cast<QCache<Key,T>*>(this)->relink(key); }
 
 template <class Key, class T>
 inline T *QCache<Key,T>::operator[](const Key &key) const
@@ -128,12 +153,29 @@ inline T *QCache<Key,T>::operator[](const Key &key) const
 
 template <class Key, class T>
 inline bool QCache<Key,T>::remove(const Key &key)
-{ if (hash.contains(key)) { unlink(hash[key]); return true; } return false; }
+{
+    typename QHash<Key, Node>::iterator i = hash.find(key);
+    if (typename QHash<Key, Node>::const_iterator(i) == hash.constEnd()) {
+        return false;
+    } else {
+        unlink(*i);
+        return true;
+    }
+}
 
 template <class Key, class T>
 inline T *QCache<Key,T>::take(const Key &key)
-{ if (!hash.contains(key)) return 0;
- Node &n = hash[key]; T *t = n.t; n.t = 0; unlink(n); return t; }
+{
+    typename QHash<Key, Node>::iterator i = hash.find(key);
+    if (i == hash.end())
+        return 0;
+
+    Node &n = *i;
+    T *t = n.t;
+    n.t = 0;
+    unlink(n);
+    return t;
+}
 
 template <class Key, class T>
 bool QCache<Key,T>::insert(const Key &akey, T *aobject, int acost)
@@ -144,10 +186,11 @@ bool QCache<Key,T>::insert(const Key &akey, T *aobject, int acost)
         return false;
     }
     trim(mx - acost);
-    Node sn(akey, aobject, acost);
-    hash.insert(akey, sn);
+    Node sn(aobject, acost);
+    typename QHash<Key, Node>::iterator i = hash.insert(akey, sn);
     total += acost;
-    Node *n = &hash[akey];
+    Node *n = &i.value();
+    n->keyPtr = &i.key();
     if (f) f->p = n;
     n->n = f;
     f = n;
@@ -162,11 +205,12 @@ void QCache<Key,T>::trim(int m)
     while (n && total > m) {
         Node *u = n;
         n = n->p;
-        if (qIsDetached(*u->t))
-            unlink(*u);
+        unlink(*u);
     }
 }
 
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
 #endif // QCACHE_H
