@@ -8,8 +8,8 @@
 /* Machine byte-order */
 #define Q_BIG_ENDIAN 4321
 #define Q_LITTLE_ENDIAN 1234
-#define QT_BUILD_KEY "x86_64 openbsd g++-4 full-config"
-#define QT_BUILD_KEY_COMPAT "amd64 OpenBSD g++-4 full-config"
+#define QT_BUILD_KEY "x86_64 openbsd clang full-config"
+#define QT_BUILD_KEY_COMPAT "amd64 OpenBSD clang full-config"
 
 #ifdef QT_BOOTSTRAPPED
 #define Q_BYTE_ORDER Q_LITTLE_ENDIAN
@@ -106,12 +106,6 @@
 # define QT_NO_S60
 #endif
 
-#if defined(QT_NO_STYLE_GTK) && defined(QT_STYLE_GTK)
-# undef QT_NO_STYLE_GTK
-#elif !defined(QT_NO_STYLE_GTK) && !defined(QT_STYLE_GTK)
-# define QT_NO_STYLE_GTK
-#endif
-
 #if defined(QT_NO_STYLE_S60) && defined(QT_STYLE_S60)
 # undef QT_NO_STYLE_S60
 #elif !defined(QT_NO_STYLE_S60) && !defined(QT_STYLE_S60)
