@@ -9,7 +9,7 @@
 #define Q_BIG_ENDIAN 4321
 #define Q_LITTLE_ENDIAN 1234
 #define QT_BUILD_KEY "generic openbsd g++-4 full-config"
-#define QT_BUILD_KEY_COMPAT "hppa OpenBSD g++-4 full-config"
+#define QT_BUILD_KEY_COMPAT "sparc64 OpenBSD g++-4 full-config"
 
 #ifdef QT_BOOTSTRAPPED
 #define Q_BYTE_ORDER Q_BIG_ENDIAN
@@ -24,7 +24,7 @@
 #endif
 /* Compile time features */
 #define QT_LARGEFILE_SUPPORT 64
-#define QT_POINTER_SIZE 4
+#define QT_POINTER_SIZE 8
 
 #ifndef QT_BOOTSTRAPPED
 
