@@ -1,36 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -40,6 +45,7 @@
 #include <QtCore/qnamespace.h>
 #include <QtCore/qrect.h>
 #include <QtCore/qpoint.h>
+#include <QtCore/qscopedpointer.h>
 #include <QtGui/qpixmap.h>
 #include <QtGui/qimage.h>
 #include <QtGui/qtextoption.h>
@@ -57,6 +63,8 @@
 
 QT_BEGIN_HEADER
 
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Gui)
 
 class QBrush;
@@ -70,6 +78,10 @@ class QPolygon;
 class QTextItem;
 class QMatrix;
 class QTransform;
+class QStaticText;
+class QGlyphRun;
+
+class QPainterPrivateDeleter;
 
 class Q_GUI_EXPORT QPainter
 {
@@ -82,11 +94,35 @@ public:
         Antialiasing = 0x01,
         TextAntialiasing = 0x02,
         SmoothPixmapTransform = 0x04,
-        HighQualityAntialiasing = 0x08
+        HighQualityAntialiasing = 0x08,
+        NonCosmeticDefaultPen = 0x10
     };
 
     Q_DECLARE_FLAGS(RenderHints, RenderHint)
 
+    class PixmapFragment {
+    public:
+        qreal x;
+        qreal y;
+        qreal sourceLeft;
+        qreal sourceTop;
+        qreal width;
+        qreal height;
+        qreal scaleX;
+        qreal scaleY;
+        qreal rotation;
+        qreal opacity;
+        static PixmapFragment Q_GUI_EXPORT create(const QPointF &pos, const QRectF &sourceRect,
+                                            qreal scaleX = 1, qreal scaleY = 1,
+                                            qreal rotation = 0, qreal opacity = 1);
+    };
+
+    enum PixmapFragmentHint {
+        OpaqueHint = 0x01
+    };
+
+    Q_DECLARE_FLAGS(PixmapFragmentHints, PixmapFragmentHint)
+
     QPainter();
     explicit QPainter(QPaintDevice *);
     ~QPainter();
@@ -125,7 +161,18 @@ public:
         CompositionMode_HardLight,
         CompositionMode_SoftLight,
         CompositionMode_Difference,
-        CompositionMode_Exclusion
+        CompositionMode_Exclusion,
+
+        // ROPs
+        RasterOp_SourceOrDestination,
+        RasterOp_SourceAndDestination,
+        RasterOp_SourceXorDestination,
+        RasterOp_NotSourceAndNotDestination,
+        RasterOp_NotSourceOrNotDestination,
+        RasterOp_NotSourceXorDestination,
+        RasterOp_NotSource,
+        RasterOp_NotSourceAndDestination,
+        RasterOp_SourceAndNotDestination
     };
     void setCompositionMode(CompositionMode mode);
     CompositionMode compositionMode() const;
@@ -175,6 +222,8 @@ public:
     void setClipping(bool enable);
     bool hasClipping() const;
 
+    QRectF clipBoundingRect() const;
+
     void save();
     void restore();
 
@@ -191,7 +240,7 @@ public:
 
     void setWorldMatrix(const QMatrix &matrix, bool combine = false);
     const QMatrix &worldMatrix() const;
-    
+
     void setWorldTransform(const QTransform &matrix, bool combine = false);
     const QTransform &worldTransform() const;
 
@@ -265,6 +314,9 @@ public:
     void drawEllipse(const QRect &r);
     inline void drawEllipse(int x, int y, int w, int h);
 
+    inline void drawEllipse(const QPointF &center, qreal rx, qreal ry);
+    inline void drawEllipse(const QPoint &center, int rx, int ry);
+
     void drawPolyline(const QPointF *points, int pointCount);
     inline void drawPolyline(const QPolygonF &polyline);
     void drawPolyline(const QPoint *points, int pointCount);
@@ -292,6 +344,13 @@ public:
     inline void drawChord(int x, int y, int w, int h, int a, int alen);
     inline void drawChord(const QRect &, int a, int alen);
 
+    void drawRoundedRect(const QRectF &rect, qreal xRadius, qreal yRadius,
+                         Qt::SizeMode mode = Qt::AbsoluteSize);
+    inline void drawRoundedRect(int x, int y, int w, int h, qreal xRadius, qreal yRadius,
+                                Qt::SizeMode mode = Qt::AbsoluteSize);
+    inline void drawRoundedRect(const QRect &rect, qreal xRadius, qreal yRadius,
+                                Qt::SizeMode mode = Qt::AbsoluteSize);
+
     void drawRoundRect(const QRectF &r, int xround = 25, int yround = 25);
     inline void drawRoundRect(int x, int y, int w, int h, int = 25, int = 25);
     inline void drawRoundRect(const QRect &r, int xround = 25, int yround = 25);
@@ -313,12 +372,17 @@ public:
                            int sx, int sy, int sw, int sh);
     inline void drawPixmap(const QPointF &p, const QPixmap &pm, const QRectF &sr);
     inline void drawPixmap(const QPoint &p, const QPixmap &pm, const QRect &sr);
-    inline void drawPixmap(const QPointF &p, const QPixmap &pm);
+    void drawPixmap(const QPointF &p, const QPixmap &pm);
     inline void drawPixmap(const QPoint &p, const QPixmap &pm);
     inline void drawPixmap(int x, int y, const QPixmap &pm);
     inline void drawPixmap(const QRect &r, const QPixmap &pm);
     inline void drawPixmap(int x, int y, int w, int h, const QPixmap &pm);
 
+    void drawPixmapFragments(const PixmapFragment *fragments, int fragmentCount,
+                             const QPixmap &pixmap, PixmapFragmentHints hints = 0);
+    void drawPixmapFragments(const QRectF *targetRects, const QRectF *sourceRects, int fragmentCount,
+                             const QPixmap &pixmap, PixmapFragmentHints hints = 0);
+
     void drawImage(const QRectF &targetRect, const QImage &image, const QRectF &sourceRect,
                    Qt::ImageConversionFlags flags = Qt::AutoColor);
     inline void drawImage(const QRect &targetRect, const QImage &image, const QRect &sourceRect,
@@ -329,7 +393,7 @@ public:
                           Qt::ImageConversionFlags flags = Qt::AutoColor);
     inline void drawImage(const QRectF &r, const QImage &image);
     inline void drawImage(const QRect &r, const QImage &image);
-    inline void drawImage(const QPointF &p, const QImage &image);
+    void drawImage(const QPointF &p, const QImage &image);
     inline void drawImage(const QPoint &p, const QImage &image);
     inline void drawImage(int x, int y, const QImage &image, int sx = 0, int sy = 0,
                           int sw = -1, int sh = -1, Qt::ImageConversionFlags flags = Qt::AutoColor);
@@ -337,10 +401,20 @@ public:
     void setLayoutDirection(Qt::LayoutDirection direction);
     Qt::LayoutDirection layoutDirection() const;
 
+#if !defined(QT_NO_RAWFONT)
+    void drawGlyphRun(const QPointF &position, const QGlyphRun &glyphRun);
+#endif
+
+    void drawStaticText(const QPointF &topLeftPosition, const QStaticText &staticText);
+    inline void drawStaticText(const QPoint &topLeftPosition, const QStaticText &staticText);
+    inline void drawStaticText(int left, int top, const QStaticText &staticText);
+
     void drawText(const QPointF &p, const QString &s);
     inline void drawText(const QPoint &p, const QString &s);
     inline void drawText(int x, int y, const QString &s);
 
+    void drawText(const QPointF &p, const QString &str, int tf, int justificationPadding);
+
     void drawText(const QRectF &r, int flags, const QString &text, QRectF *br=0);
     void drawText(const QRect &r, int flags, const QString &text, QRect *br=0);
     inline void drawText(int x, int y, int w, int h, int flags, const QString &text, QRect *br=0);
@@ -361,6 +435,18 @@ public:
     inline void fillRect(int x, int y, int w, int h, const QBrush &);
     void fillRect(const QRect &, const QBrush &);
 
+    void fillRect(const QRectF &, const QColor &color);
+    inline void fillRect(int x, int y, int w, int h, const QColor &color);
+    void fillRect(const QRect &, const QColor &color);
+
+    inline void fillRect(int x, int y, int w, int h, Qt::GlobalColor c);
+    inline void fillRect(const QRect &r, Qt::GlobalColor c);
+    inline void fillRect(const QRectF &r, Qt::GlobalColor c);
+
+    inline void fillRect(int x, int y, int w, int h, Qt::BrushStyle style);
+    inline void fillRect(const QRect &r, Qt::BrushStyle style);
+    inline void fillRect(const QRectF &r, Qt::BrushStyle style);
+
     void eraseRect(const QRectF &);
     inline void eraseRect(int x, int y, int w, int h);
     inline void eraseRect(const QRect &);
@@ -377,6 +463,9 @@ public:
     static QPaintDevice *redirected(const QPaintDevice *device, QPoint *offset = 0);
     static void restoreRedirected(const QPaintDevice *device);
 
+    void beginNativePainting();
+    void endNativePainting();
+
 #ifdef QT3_SUPPORT
 
     inline QT3_SUPPORT void setBackgroundColor(const QColor &color) { setBackground(color); }
@@ -454,7 +543,7 @@ private:
     Q_DISABLE_COPY(QPainter)
     friend class Q3Painter;
 
-    QPainterPrivate *d_ptr;
+    QScopedPointer<QPainterPrivate> d_ptr;
 
     friend class QFontEngine;
     friend class QFontEngineBox;
@@ -464,12 +553,16 @@ private:
     friend class QFontEngineXLFD;
     friend class QWSManager;
     friend class QPaintEngine;
+    friend class QPaintEngineExPrivate;
+    friend class QOpenGLPaintEngine;
+    friend class QVGPaintEngine;
     friend class QX11PaintEngine;
     friend class QX11PaintEnginePrivate;
     friend class QWin32PaintEngine;
     friend class QWin32PaintEnginePrivate;
     friend class QRasterPaintEngine;
     friend class QAlphaPaintEngine;
+    friend class QPreviewPaintEngine;
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(QPainter::RenderHints)
@@ -616,11 +709,33 @@ inline void QPainter::drawRoundRect(const QRect &rect, int xRnd, int yRnd)
     drawRoundRect(QRectF(rect), xRnd, yRnd);
 }
 
+inline void QPainter::drawRoundedRect(int x, int y, int w, int h, qreal xRadius, qreal yRadius,
+                            Qt::SizeMode mode)
+{
+    drawRoundedRect(QRectF(x, y, w, h), xRadius, yRadius, mode);
+}
+
+inline void QPainter::drawRoundedRect(const QRect &rect, qreal xRadius, qreal yRadius,
+                            Qt::SizeMode mode)
+{
+    drawRoundedRect(QRectF(rect), xRadius, yRadius, mode);
+}
+
 inline void QPainter::drawEllipse(int x, int y, int w, int h)
 {
     drawEllipse(QRect(x, y, w, h));
 }
 
+inline void QPainter::drawEllipse(const QPointF &center, qreal rx, qreal ry)
+{
+    drawEllipse(QRectF(center.x() - rx, center.y() - ry, 2 * rx, 2 * ry));
+}
+
+inline void QPainter::drawEllipse(const QPoint &center, int rx, int ry)
+{
+    drawEllipse(QRect(center.x() - rx, center.y() - ry, 2 * rx, 2 * ry));
+}
+
 inline void QPainter::drawArc(const QRect &r, int a, int alen)
 {
     drawArc(QRectF(r), a, alen);
@@ -671,6 +786,42 @@ inline void QPainter::fillRect(int x, int y, int w, int h, const QBrush &b)
     fillRect(QRect(x, y, w, h), b);
 }
 
+inline void QPainter::fillRect(int x, int y, int w, int h, const QColor &b)
+{
+    fillRect(QRect(x, y, w, h), b);
+}
+
+inline void QPainter::fillRect(int x, int y, int w, int h, Qt::GlobalColor c)
+{
+    fillRect(QRect(x, y, w, h), QColor(c));
+}
+
+inline void QPainter::fillRect(const QRect &r, Qt::GlobalColor c)
+{
+    fillRect(r, QColor(c));
+}
+
+inline void QPainter::fillRect(const QRectF &r, Qt::GlobalColor c)
+{
+    fillRect(r, QColor(c));
+}
+
+inline void QPainter::fillRect(int x, int y, int w, int h, Qt::BrushStyle style)
+{
+    fillRect(QRectF(x, y, w, h), QBrush(style));
+}
+
+inline void QPainter::fillRect(const QRect &r, Qt::BrushStyle style)
+{
+    fillRect(QRectF(r), QBrush(style));
+}
+
+inline void QPainter::fillRect(const QRectF &r, Qt::BrushStyle style)
+{
+    fillRect(r, QBrush(style));
+}
+
+
 inline void QPainter::setBrushOrigin(int x, int y)
 {
     setBrushOrigin(QPoint(x, y));
@@ -696,14 +847,9 @@ inline void QPainter::drawPixmap(const QRect &targetRect, const QPixmap &pixmap,
     drawPixmap(QRectF(targetRect), pixmap, QRectF(sourceRect));
 }
 
-inline void QPainter::drawPixmap(const QPointF &p, const QPixmap &pm)
-{
-    drawPixmap(QRectF(p.x(), p.y(), -1, -1), pm, QRectF());
-}
-
 inline void QPainter::drawPixmap(const QPoint &p, const QPixmap &pm)
 {
-    drawPixmap(QRectF(p.x(), p.y(), -1, -1), pm, QRectF());
+    drawPixmap(QPointF(p), pm);
 }
 
 inline void QPainter::drawPixmap(const QRect &r, const QPixmap &pm)
@@ -713,7 +859,7 @@ inline void QPainter::drawPixmap(const QRect &r, const QPixmap &pm)
 
 inline void QPainter::drawPixmap(int x, int y, const QPixmap &pm)
 {
-    drawPixmap(QRectF(x, y, -1, -1), pm, QRectF());
+    drawPixmap(QPointF(x, y), pm);
 }
 
 inline void QPainter::drawPixmap(int x, int y, int w, int h, const QPixmap &pm)
@@ -777,20 +923,28 @@ inline void QPainter::drawImage(const QRect &r, const QImage &image)
     drawImage(r, image, QRectF(0, 0, image.width(), image.height()));
 }
 
-inline void QPainter::drawImage(const QPointF &p, const QImage &image)
-{
-    drawImage(QRectF(p.x(), p.y(), -1, -1), image, QRectF(0, 0, image.width(), image.height()));
-}
-
 inline void QPainter::drawImage(const QPoint &p, const QImage &image)
 {
-    drawImage(QRectF(p.x(), p.y(), -1, -1), image, QRectF(0, 0, image.width(), image.height()));
+    drawImage(QPointF(p), image);
 }
 
 inline void QPainter::drawImage(int x, int y, const QImage &image, int sx, int sy, int sw, int sh,
                                 Qt::ImageConversionFlags flags)
 {
-    drawImage(QRectF(x, y, -1, -1), image, QRectF(sx, sy, sw, sh), flags);
+    if (sx == 0 && sy == 0 && sw == -1 && sh == -1 && flags == Qt::AutoColor)
+        drawImage(QPointF(x, y), image);
+    else
+        drawImage(QRectF(x, y, -1, -1), image, QRectF(sx, sy, sw, sh), flags);
+}
+
+inline void QPainter::drawStaticText(const QPoint &p, const QStaticText &staticText)
+{
+    drawStaticText(QPointF(p), staticText);
+}
+
+inline void QPainter::drawStaticText(int x, int y, const QStaticText &staticText)
+{
+    drawStaticText(QPointF(x, y), staticText);
 }
 
 inline void QPainter::drawTextItem(const QPoint &p, const QTextItem &ti)
@@ -850,6 +1004,8 @@ inline void QPainter::drawPicture(const QPoint &pt, const QPicture &p)
 }
 #endif
 
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
 #endif // QPAINTER_H
